@@ -33,4 +33,7 @@ TLS_ENFORCE = not os.getenv('DISABLE_TLS_ENFORCE') == '1'
 
 TMPDIR = tempfile.gettempdir()
 
+#: The location of the Unimatrix Configuration File.
+UNIMATRIX_CONFIG_FILE = os.getenv('UNIMATRIX_CONFIG_FILE') or 'app.conf'
+
 VARDIR = os.getenv('APP_VARDIR', '/var/lib/app')
