@@ -48,6 +48,13 @@ HTTP_CORS_EXPOSE_HEADERS: tuple = environ.parselist(
 HTTP_CORS_TTL: int = environ.parseint(
     os.environ, 'HTTP_CORS_TTL', default=600)
 
+#: Path to the URL configuration file.
+HTTP_URLCONF = os.getenv('HTTP_URLCONF') or 'etc/urlconf.yml'
+
+
+#: The default log level.
+LOG_LEVEL = os.getenv('LOG_LEVEL') or 'WARNING'
+
 #: The filepath to a PEM-encoded private key (either RSA or elliptic curve with
 #: a supported curve) that is used by the application to sign access tokens when
 #: communicating with other services. Implementations must ensure that when
@@ -56,6 +63,11 @@ HTTP_CORS_TTL: int = environ.parseint(
 #: relative to the ``iss`` claim that it specifies on the tokens.
 OAUTH2_ACTOR_KEY: str = os.getenv('OAUTH2_ACTOR_KEY')
 
+#: Additional audiences that the server accepts.
+OAUTH2_AUDIENCES: tuple = environ.parselist(
+    os.environ, 'OAUTH2_AUDIENCES', sep=';'
+)
+
 #: The list of Security Token Services (STSs) that the application trusts. The
 #: services are expected to provide a ``/.well-known/openid-configuration``
 #: URL, from which the JWKS holding its keys can be discovered. Multiple STSs
@@ -64,5 +76,8 @@ OAUTH2_TRUSTED_STS: tuple = environ.parselist(
     os.environ, 'OAUTH2_TRUSTED_STS', sep=";"
 )
 
+#: The URL at which the application may exchange security tokens.
+OAUTH2_TOKEN_EXCHANGE_URL = os.getenv('OAUTH2_TOKEN_EXCHANGE_URL')
+
 #: The default secret key. This is an opaque string.
 SECRET_KEY: str = os.getenv('SECRET_KEY')
